@@ -8,7 +8,7 @@
 import pytest
 
 
-@pytest.mark.sphinx('html', testroot='sphinx')
+@pytest.mark.sphinx("html", testroot="sphinx")
 def test_sphinx(app, warning) -> None:
     app.build()
     assert not warning.getvalue()
